@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-import re, sys
+import re, sys, shelve
 import logging as log
 from pdb import set_trace
 import urllib.request
@@ -14,9 +14,9 @@ def update_ddns_server(update_url, verbose=False, update=True):
     if verbose:
         log.basicConfig(level=log.DEBUG)
     log.debug("External IP address {}".format(str(external_ip)))
-    prev_ext_ip = read_ip_addy()
+    prev_ext_ip = read_ip_addy(update_url)
     log.debug("Old IP: {}".format(prev_ext_ip))
-    save_ip_addy(external_ip)
+    save_ip_addy(external_ip,update_url)
     changed = ip_addy_changed(external_ip, prev_ext_ip)
     if changed:
         log.debug("IP changed")
@@ -39,10 +39,21 @@ def touch_ddns_server(url):
     resp = urllib.request.urlopen(url).read()
     log.debug("Response:\n{}".format(resp))
 
-def save_ip_addy(ip):
-    log.debug("Saving IP addy")
-    f = open(ip_file, 'w')
-    f.write(ip)
+def save_ip_addy(new_ip, update_url):
+    ip_updates = shelve.open(ip_file)
+    ip_updates[update_url] = new_ip
+    log.debug("Saving IP address: {}, under update URL: {}".format(new_ip, update_url))
+    ip_updates.close
+
+def read_ip_addy(update_url):
+    ip_updates = shelve.open(ip_file)
+    if ip_updates:
+        if not update_url in ip_updates:
+            return None
+        else:
+            ip = ip_updates[update_url]
+            log.debug("IP address: {} retrieved for update URL: {}".format(ip, update_url))
+            return ip 
 
 def extract_ip(html):
     # set_trace()
@@ -60,13 +71,6 @@ def get_external_ip():
     ip = extract_ip(html)
     return ip
 
-def read_ip_addy():
-    try:
-        f = open(ip_file, 'r')
-    except FileNotFoundError:
-        return None
-    ip = f.read().strip()
-    return ip
 
 #################################
 # TESTS
@@ -79,7 +83,8 @@ def test_extract_ip():
 
 if __name__ == '__main__':
     # set_trace()
-    update_ddns_server(update_url="", verbose=True, update=False)
+    update_ddns_server(update_url="abc123", verbose=True, update=False)
+    update_ddns_server(update_url="abc124", verbose=True, update=False)
 
 
 
